import numpy as np
import pandas as pd
import stan
import pickle

inf_nm = input('Input data file(*.csv) = ') 
dframe = pd.read_csv(inf_nm)                #  データの読み込み

with open('in_dframe.pkl', 'wb') as f:
    pickle.dump(dframe, f)                  #   読み込みデータの保存

df_keys = dframe.keys()
x_name = df_keys[1]
y_name = df_keys[2]
print(x_name, y_name)
x = dframe[x_name].values
x = x[np.isnan(x)==False]       #  空セルデータの削除
x = np.array(x, dtype=int)
print('X =\n', x)
y = dframe[y_name].values
y = y[np.isnan(y)==False]       #  空セルデータの削除
y = np.array(y, dtype=int)
print('Y =\n', y)

mean1 = np.mean(x)
sd1 = np.std(x)
print('mean1 =', mean1, '   sd1 =', sd1)
mean2 = np.mean(y)
sd2 = np.std(y)
print('mean2 =', mean2, '   sd2 =', sd2)

max1 = np.max(x)
max2 = np.max(y)
print('max1 =',max1)
print('max2 =',max2)

stan_code = """
    data {
        int n1;
        array[n1] int x;
        int n2;
        array[n2] int y;
        real max1;
        real max2;
    }
    parameters {
        real<lower=0, upper=1> vlmbd1;
        real<lower=0, upper=1> vlmbd2;
    }
    transformed parameters {
        /*
                 Parameters rescaled
        */
        real lmbd1;
        real lmbd2;
        lmbd1 = 0.001 + vlmbd1*max1;
        lmbd2 = 0.001 + vlmbd2*max2;
    }
    model {
        vlmbd1 ~ beta(1,1);
        vlmbd2 ~ beta(1,2);
        x ~ poisson(lmbd1);
        y ~ poisson(lmbd2);
    }
    generated quantities {
        real diff_lmbd;
        diff_lmbd = lmbd1 - lmbd2;
    }
"""

Data = {'n1':len(x), 'x':x, 'max1':max1,
        'n2':len(y), 'y':y, 'max2':max2}

sm = stan.build(stan_code, data=Data)
fit = sm.sample()

pd_fit_frame = fit.to_frame()
with open('fit.pkl', 'wb') as f:
    pickle.dump(pd_fit_frame,f)    #   MCMC samples saved
print('fit.pkl was saved.')

