import numpy as np
import pandas as pd
import pickle
import matplotlib.pyplot as plt
import seaborn as sb
import scipy.stats as ss

with open('in_dframe.pkl', 'rb') as f:
    dframe = pickle.load(f)

df_keys = dframe.keys()
x_name = df_keys[1]
y_name = df_keys[2]
print(x_name, y_name)
x = dframe[x_name].values
x = x[np.isnan(x)==False]       #  空セルデータの削除
x = np.array(x, dtype=int)
print('X =\n', x)
y = dframe[y_name].values
y = y[np.isnan(y)==False]       #  空セルデータの削除
y = np.array(y, dtype=int)
print('Y =\n', y)

mean1 = np.mean(x)
sd1 = np.std(x)
print('mean1 =', mean1, '   sd1 =', sd1)
mean2 = np.mean(y)
sd2 = np.std(y)
print('mean2 =', mean2, '   sd2 =', sd2)

max1 = np.max(x)
max2 = np.max(y)
print('max1 =',max1)
print('max2 =',max2)

with open('fit.pkl', 'rb') as f:
    pd_fit_frame = pickle.load(f)

lmbd1 = np.median(pd_fit_frame['lmbd1'])
lmbd2 = np.median(pd_fit_frame['lmbd2'])
"""
       パラメータlmbd1とlmbd2の事後分布
"""
sb.kdeplot(pd_fit_frame['lmbd1'], label='lmbd1')
sb.kdeplot(pd_fit_frame['lmbd2'], label='lmbd2')
plt.title('Posterior distributions' +
          f'\nlmbd1={lmbd1:.1f},  lmbd2={lmbd2:.1f}')
plt.xlabel('lmbd', fontsize=14)
plt.legend()
plt.show()
"""
     パラメータの差lmbd1-lmbd2の事後分布
"""
diff_lmbd = pd_fit_frame['diff_lmbd']
pos_diff = diff_lmbd > 0
neg_diff = diff_lmbd < 0
prob_pos = np.mean(pos_diff)
prob_neg = np.mean(neg_diff)
plt.title('Posterior distribution' +
          f'\nP(lmbd1>lmbd2)={prob_pos:.5f},  P(lmbd1<lmbd2)={prob_neg:.5f}')
sb.kdeplot(diff_lmbd)
plt.xlabel('lmbd1-lmbd2', fontsize=14)
plt.show()
"""
        データのヒストグラムと
        事後分布の中央値をパラメータ値とする
        Probabilituy Mass Functions
"""
maxxy = max1 if max1 > max2 else max2
minxy = np.min(x) if np.min(x) < np.min(y) else np.min(y)
xy_coord = np.arange(minxy, maxxy+1) # np.linspace(minxy, maxxy, 1000)
y1_coord = ss.poisson.pmf(xy_coord, mu=lmbd1)
y2_coord = ss.poisson.pmf(xy_coord, mu=lmbd2)
plt.hist(x, density=True, color='b', alpha=0.3, label=x_name)
plt.hist(y, density=True, color='orange', alpha=0.3, label=y_name)
plt.title(f'lmbd1={lmbd1:.1f},  lmbd2={lmbd2:.1f}')
plt.plot(xy_coord, y1_coord, 'o', color='b', label=x_name)
plt.plot(xy_coord, y2_coord, 'o', color='orange', label=y_name)

plt.ylabel('Prob.Mass/Density')
plt.legend()
plt.tight_layout()
plt.show()

